@@ -475,10 +475,8 @@ _wrap_pyg_variant_type_from_string (PyObject *self, PyObject *args)
 
     py_type = _pygi_type_import_by_name ("GLib", "VariantType");
 
-    if (PyType_IsSubtype (py_type, &PyGIBoxed_Type))
-        py_variant = _pygi_boxed_new ( (PyTypeObject *) py_type, type_string, FALSE);
-    else
-        py_variant = _pygi_struct_new ( (PyTypeObject *) py_type, type_string, FALSE);
+    py_variant = _pygi_boxed_new ( (PyTypeObject *) py_type, type_string, FALSE);
+
     return py_variant;
 }
 
